require 'spec_helper'

describe 'pe_mcollective' do
  before :all do
    @facter_facts = {
      'osfamily'              => 'RedHat',
      'lsbmajdistrelease'     => '6',
      'puppetversion'         => '2.7.6 (Puppet Enterprise 2.0.0)',
      'fact_is_puppetmaster'  => 'true',
      'fact_is_puppetconsole' => 'true',
      'fact_is_puppetagent'   => 'true',
      'fact_stomp_server'     => 'testagent',
      'fact_stomp_port'       => '6163',
    }
  end

  let :facts do
    @facter_facts
  end

  let :wrapper do
    '/etc/puppetlabs/activemq/activemq-wrapper.conf'
  end

  it { should contain_class 'pe_mcollective' }

  describe '/opt/puppet/libexec/mcollective/mcollective' do
    it do
      should create_resource('file', '/opt/puppet/libexec/mcollective/mcollective/util').with_param('mode','0755')
    end
  end

  describe '/etc/puppetlabs/mcollective/server.cfg' do
    it do
      should contain_file('/etc/puppetlabs/mcollective/server.cfg').with_notify('Service[mcollective]')
    end
  end

  describe '#10961 ActiveMQ Java Heap Class Param' do
    let :params do
      { :activemq_heap_mb => '1024' }
    end
    it 'should be a class parameter' do
      should contain_file(wrapper).with_content(/wrapper\.java\.initmemory=#{params[:activemq_heap_mb]}/)
      should contain_file(wrapper).with_content(/wrapper\.java\.maxmemory=#{params[:activemq_heap_mb]}/)
    end
  end

  describe '#10961 ActiveMQ Java Heap Node Param' do
    let :facts do
      @facter_facts.merge({'activemq_heap_mb' => '2048'})
    end
    it 'should be a node parameter' do
      should contain_file(wrapper).with_content(/wrapper\.java\.initmemory=#{facts['activemq_heap_mb']}/)
      should contain_file(wrapper).with_content(/wrapper\.java\.maxmemory=#{facts['activemq_heap_mb']}/)
    end
  end
end
